contracts\_lib\_py.agreements.agreement\_manager module
=======================================================

.. automodule:: contracts_lib_py.agreements.agreement_manager
   :members:
   :undoc-members:
   :show-inheritance:
